@@ -1,16 +1,20 @@
 from __future__ import annotations
 
+import io
+import re
+import sys
 from numbers import Number
 
 import numpy as np
 import pytest
 
 import xarray as xr
-from xarray.backends.api import _get_default_engine
+from xarray.backends.writers import get_default_netcdf_write_engine
 from xarray.tests import (
     assert_identical,
     assert_no_warnings,
     requires_dask,
+    requires_h5netcdf,
     requires_netCDF4,
     requires_scipy,
 )
@@ -18,15 +22,97 @@ from xarray.tests import (
 
 @requires_netCDF4
 @requires_scipy
-def test__get_default_engine() -> None:
-    engine_remote = _get_default_engine("http://example.org/test.nc", allow_remote=True)
-    assert engine_remote == "netcdf4"
+@requires_h5netcdf
+def test_get_default_netcdf_write_engine() -> None:
+    assert xr.get_options()["netcdf_engine_order"] == ("netcdf4", "h5netcdf", "scipy")
 
-    engine_gz = _get_default_engine("/example.gz")
-    assert engine_gz == "scipy"
+    engine = get_default_netcdf_write_engine("", format=None)
+    assert engine == "netcdf4"
 
-    engine_default = _get_default_engine("/example")
-    assert engine_default == "netcdf4"
+    engine = get_default_netcdf_write_engine("", format="NETCDF4")
+    assert engine == "netcdf4"
+
+    engine = get_default_netcdf_write_engine("", format="NETCDF4_CLASSIC")
+    assert engine == "netcdf4"
+
+    engine = get_default_netcdf_write_engine("", format="NETCDF3_CLASSIC")
+    assert engine == "netcdf4"
+
+    engine = get_default_netcdf_write_engine(io.BytesIO(), format=None)
+    assert engine == "h5netcdf"
+
+    engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF4")
+    assert engine == "h5netcdf"
+
+    engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF3_CLASSIC")
+    assert engine == "scipy"
+
+    engine = get_default_netcdf_write_engine("path.zarr#mode=nczarr", format=None)
+    assert engine == "netcdf4"
+
+    with xr.set_options(netcdf_engine_order=["netcdf4", "scipy", "h5netcdf"]):
+        engine = get_default_netcdf_write_engine(io.BytesIO(), format=None)
+        assert engine == "scipy"
+
+        engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF4")
+        assert engine == "h5netcdf"
+
+        engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF3_CLASSIC")
+        assert engine == "scipy"
+
+    with xr.set_options(netcdf_engine_order=["h5netcdf", "scipy", "netcdf4"]):
+        engine = get_default_netcdf_write_engine("", format=None)
+        assert engine == "h5netcdf"
+
+        engine = get_default_netcdf_write_engine("", format="NETCDF4")
+        assert engine == "h5netcdf"
+
+        engine = get_default_netcdf_write_engine("", format="NETCDF4_CLASSIC")
+        assert engine == "netcdf4"
+
+        engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF4")
+        assert engine == "h5netcdf"
+
+        engine = get_default_netcdf_write_engine("", format="NETCDF3_CLASSIC")
+        assert engine == "scipy"
+
+        engine = get_default_netcdf_write_engine(io.BytesIO(), format="NETCDF3_CLASSIC")
+        assert engine == "scipy"
+
+
+@requires_h5netcdf
+def test_default_engine_h5netcdf(monkeypatch):
+    """Test the default netcdf engine when h5netcdf is the only importable module."""
+
+    monkeypatch.delitem(sys.modules, "netCDF4", raising=False)
+    monkeypatch.delitem(sys.modules, "scipy", raising=False)
+    monkeypatch.setattr(sys, "meta_path", [])
+
+    engine = get_default_netcdf_write_engine("", format=None)
+    assert engine == "h5netcdf"
+
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            "cannot write NetCDF files with format='NETCDF3_CLASSIC' because "
+            "none of the suitable backend libraries (SUITABLE_BACKENDS) are installed"
+        ).replace("SUITABLE_BACKENDS", r"(scipy, netCDF4)|(netCDF4, scipy)"),
+    ):
+        get_default_netcdf_write_engine("", format="NETCDF3_CLASSIC")
+
+
+def test_default_engine_nczarr_no_netcdf4_python(monkeypatch):
+    monkeypatch.delitem(sys.modules, "netCDF4", raising=False)
+    monkeypatch.setattr(sys, "meta_path", [])
+
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            "cannot write NetCDF files in NCZarr format because "
+            "none of the suitable backend libraries (netCDF4) are installed"
+        ),
+    ):
+        get_default_netcdf_write_engine("#mode=nczarr", format=None)
 
 
 def test_custom_engine() -> None:
@@ -201,3 +287,39 @@ class TestPreferredChunks:
                 chunks=dict(zip(initial[self.var_name].dims, req_chunks, strict=True)),
             )
         self.check_dataset(initial, final, explicit_chunks(req_chunks, shape))
+
+    @pytest.mark.parametrize("create_default_indexes", [True, False])
+    def test_default_indexes(self, create_default_indexes):
+        """Create default indexes if the backend does not create them."""
+        coords = xr.Coordinates({"x": ("x", [0, 1]), "y": list("abc")}, indexes={})
+        initial = xr.Dataset({"a": ("x", [1, 2])}, coords=coords)
+
+        with assert_no_warnings():
+            final = xr.open_dataset(
+                initial,
+                engine=PassThroughBackendEntrypoint,
+                create_default_indexes=create_default_indexes,
+            )
+
+        if create_default_indexes:
+            assert all(name in final.xindexes for name in ["x", "y"])
+        else:
+            assert len(final.xindexes) == 0
+
+    @pytest.mark.parametrize("create_default_indexes", [True, False])
+    def test_default_indexes_passthrough(self, create_default_indexes):
+        """Allow creating indexes in the backend."""
+
+        initial = xr.Dataset(
+            {"a": (["x", "y"], [[1, 2, 3], [4, 5, 6]])},
+            coords={"x": ("x", [0, 1]), "y": ("y", list("abc"))},
+        ).stack(z=["x", "y"])
+
+        with assert_no_warnings():
+            final = xr.open_dataset(
+                initial,
+                engine=PassThroughBackendEntrypoint,
+                create_default_indexes=create_default_indexes,
+            )
+
+        assert initial.coords.equals(final.coords)
